#ifndef __DISPLAY_H
#define __DISPLAY_H

#define lcdSm  0
#define lcdSm_ctl (*(volatile unsigned char *)(0x7FF8))
#define lcdSm_dat (*(volatile unsigned char *)(0x7FF9))

#define lcdLg1 1
#define lcdLg1_ctl (*(volatile unsigned char *)(0x6000))
#define lcdLg1_dat (*(volatile unsigned char *)(0x6100))

#define lcdLg2 2
#define lcdLg2_ctl (*(volatile unsigned char *)(0x6200))
#define lcdLg2_dat (*(volatile unsigned char *)(0x6300))


//      HD44780 Instruction Set             DB7 DB6 DB5 DB4 DB3 DB2 DB1 DB0
//      =======================             === === === === === === === ===
#define Clear_Display                0x01 // 0   0   0   0   0   0   0   1

#define Return_Home                  0x02 // 0   0   0   0   0   0   1   *

#define Set_Entry_Mode               0x04 // 0   0   0   0   0   1  I/D  S

#define Set_Display                  0x08 // 0   0   0   0   1   D   C   B

#define Set_Cursor_and_Display_Shift 0x10 // 0   0   0   1  S/C R/L  *   *

#define Set_Function                 0x20 // 0   0   1   DL  N   F   *   *

#define Set_CGRAM_Address            0x40 // 0   1   A   A   A   A   A   A

#define Set_DDRAM_Address            0x80 // 1   A   A   A   A   A   A   A

//      HD44780 Parameters 
//      ==================

//      Set_Entry_Mode
//      ==============
#define Decrement_Address            0x00 // .   .   .   .   .   .   0   .
#define Increment_Address            0x02 // .   .   .   .   .   .   1   .

#define Shift_Display_Off            0x00 // .   .   .   .   .   .   .   0
#define Shift_Display_On             0x01 // .   .   .   .   .   .   .   1

//      Set_Display
//      ===========
#define Display_Off                  0x00 // .   .   .   .   .   0   .   .
#define Display_On                   0x04 // .   .   .   .   .   1   .   .

#define Cursor_Off                   0x00 // .   .   .   .   .   .   0   .
#define Cursor_On                    0x02 // .   .   .   .   .   .   1   .

#define Blink_Off                    0x00 // .   .   .   .   .   .   .   0
#define Blink_On                     0x01 // .   .   .   .   .   .   .   1

//      Set_Cursor_and_Display_Shift
//      ============================
#define Cursor                       0x00 // .   .   .   .   0   .   .   .
#define Display_and_Cursor           0x08 // .   .   .   .   1   .   .   .

#define Left                         0x00 // .   .   .   .   .   0   .   .
#define Right                        0x04 // .   .   .   .   .   1   .   .

//      Set_Function
//      ============
#define Data_Length_4                0x00 // .   .   .   0   .   .   .   .
#define Data_Length_8                0x10 // .   .   .   1   .   .   .   .

#define One_Display_Line             0x00 // .   .   .   .   0   .   .   .
#define Two_Display_Lines            0x08 // .   .   .   .   1   .   .   .

#define Font_5x7                     0x00 // .   .   .   .   .   0   .   .
#define Font_5x10                    0x04 // .   .   .   .   .   1   .   .

#define Line2_Offset 0x40

extern void dispPause(void);
extern void dispPutIns(int d, int ins);
extern void dispPutChar(int d, unsigned char ch);
extern void dispPutStr(int d, char Str[]);
extern void dispInitDisplay(int d);
extern void dispGotoXY(int d, int x, int y);
extern void dispPutCharXY(int d, int x, int y, char ch);
extern void dispPutStrXY(int d, int x, int y, char str[]);
extern void dispInit(void);

#endif
